import java.security.Policy;

public class Main {

	public static void main(String[] args) {
		
		// Policy and security manager
		Policy.setPolicy(new PluginSecurityPolicy());
		System.setSecurityManager(new SecurityManager());     
		
		// Get a list of plugin names.
		PluginLoader loader = new PluginLoader();
		loader.setPluginDirectory("plugins");
		String[] pluginNames = loader.listPlugins();
		
		// For each plugin, get the class, instantiate it, and print the message.
		for(String pluginName: pluginNames) {
			Class<?> pluginClass = loader.loadClass(pluginName);

			if(pluginClass != null) {
				try {
					Plugin plugin = (Plugin)pluginClass.newInstance();
					System.out.println(plugin.getMessage());
				} catch (InstantiationException | IllegalAccessException e) {
					System.out.println("Error loading plugin " + pluginName);
				}
			}
		}
	}
}
